@@ -3,18 +3,17 @@
 # Sep 2020
 
 from tkinter import *
-from tkinter import ttk, filedialog
+from tkinter import ttk, filedialog, messagebox
 
 # set MPL backend
 import matplotlib as mpl
 mpl.use('TkAgg')
 
-import sys, os, datetime
+import sys, os, datetime, yaml, subprocess, textwrap
 import matplotlib.pyplot as plt
 import numpy as np
 import weakref as wref
 import subprocess
-import yaml
 
 from bccd import __version__, icon_path
 from bccd.backend.PltTracker import PltTracker
@@ -35,9 +34,11 @@ class bccd(object):
         Build the mainframe and set up the runloop for the tkinter GUI. 
         
         Data Fields:
-            
+       
+            draw_new_target: BooleanVar, if true, draw new also draws targets
             mainframe: frame for root
             notebook: notebook for adding files
+            sync: BooleanVar, if true, sync data with remote servers
             tabs: list of fits_tabs objects which have been fetched fits_tabs
             targets: list of popup_target objects
     """
@@ -153,6 +154,9 @@ class bccd(object):
                       'alpha':1., 
                       'fillstyle':'full'}
         
+        # minimum window size
+        root.minsize(400,10)
+        
         # main frame
         self.mainframe = ttk.Frame(root, pad=5)
         self.mainframe.grid(column=0, row=0, sticky=(N, W, E, S))
@@ -166,11 +170,25 @@ class bccd(object):
         
         # File
         menu_file = Menu(menubar)
+        
         menu_file.add_command(label='Load From Yaml', command=self.load)
+        menu_file.add_command(label='Show keyboard shortcuts', command=self.show_keys)
         menu_file.add_command(label='Close All Figures', command=self.close_all)
         menu_file.add_command(label='Exit', command=sys.exit)
         menubar.add_cascade(menu=menu_file, label='File')
         
+        # sync
+        self.sync = BooleanVar()
+        self.sync.set(True)
+        menubar.add_checkbutton(label="Remote Sync",\
+                variable=self.sync,selectcolor=colors.selected)
+        
+        # draw with targets
+        self.draw_new_target = BooleanVar()
+        self.draw_new_target.set(True)
+        menubar.add_checkbutton(label="Draw New With Targets",\
+                variable=self.draw_new_target, selectcolor=colors.selected)
+        
         # Top Notebook --------------------------------------------------------
         noteframe = ttk.Frame(self.mainframe, relief='sunken', pad=5)
         self.notebook = ttk.Notebook(noteframe)
@@ -319,6 +337,9 @@ class bccd(object):
     def get_data(self):
         """Fetch the images from a remote location"""
         
+        if not self.sync.get():
+            return
+        
         for loc in self.data_remote:
             
             # make destination location 
@@ -326,8 +347,14 @@ class bccd(object):
             os.makedirs(dest, exist_ok=True)
             
             # rsync
-            print("Fetching data from %s..." % loc)
-            subprocess.call(['rsync', '-az', '--min-size=1', os.path.join(loc,'*'), dest])
+            print("Fetching data from %s:" % loc,flush=True)
+            subprocess.call(['rsync', 
+                             '-az', 
+                             '--progress', 
+                             '--update',
+                             '--inplace',
+                             '--human-readable',
+                             os.path.join(loc,'*'), dest])
             
     # ====================================================================== #
     def key_ctrl_l(self,*args):
@@ -473,3 +500,23 @@ class bccd(object):
         except Exception as err:
             print(err)
         
+    # ======================================================================= #
+    def show_keys(self):
+        """
+            Show message box with keyboard shortcuts
+        """
+        message = \
+        """
+        Command             Action
+        
+        <ctrl> + <l>        Add last
+        <ctrl> + <o>        Add image
+        <ctrl> + <t>        New target
+        <ctrl> + <w>        Close tab
+        <ctrl> + <#>        Switch tab
+        <return>            Superimpose
+        <ctrl> + <return>   Draw new
+        """
+        
+        messagebox.showinfo(title="Keyboard Shortcuts",
+                            message=textwrap.dedent(message))
